==> haskell-http-media-0.7.1.3-5-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.3
id: http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
key: http-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
author: Timothy Jones
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
abi: 1c3d4c59e289aa18c517f60d1d5304a1
exposed: True
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
import-dirs: /usr/lib/ghc-8.6.4/site-local/http-media-0.7.1.3
library-dirs: /usr/lib/ghc-8.6.4/site-local/http-media-0.7.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/http-media-0.7.1.3
hs-libraries: HShttp-media-0.7.1.3-7B92MKhk7rgJnZ6fbAqMYu
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.0.11-F6T6GvbsLJXGLQlCHITWZu containers-0.6.0.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-media-0.7.1.3-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-media.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-media
version: 0.7.1.3
id: http-media-0.7.1.3-526FRqXrDV23kO6QPxcRZi
key: http-media-0.7.1.3-526FRqXrDV23kO6QPxcRZi
license: MIT
copyright: (c) 2012-2017 Timothy Jones
maintainer: Timothy Jones <tim@zmthy.net>
author: Timothy Jones
homepage: https://github.com/zmthy/http-media
synopsis: Processing HTTP Content-Type and Accept headers
description:
    This library is intended to be a comprehensive solution to parsing and
    selecting quality-indexed values in HTTP headers.  It is capable of
    parsing both media types and language parameters from the Accept and
    Content header families, and can be extended to match against other
    accept headers as well.  Selecting the appropriate header value is
    achieved by comparing a list of server options against the
    quality-indexed values supplied by the client.
    .
    In the following example, the Accept header is parsed and then matched
    against a list of server options to serve the appropriate media using
    '\''mapAcceptMedia'\'':
    .
    > getHeader >>= maybe send406Error sendResourceWith . mapAcceptMedia
    >     [ ("text/html",        asHtml)
    >     , ("application/json", asJson)
    >     ]
    .
    Similarly, the Content-Type header can be used to produce a parser for
    request bodies based on the given content type with '\''mapContentMedia'\'':
    .
    > getContentType >>= maybe send415Error readRequestBodyWith . mapContentMedia
    >     [ ("application/json", parseJson)
    >     , ("text/plain",       parseText)
    >     ]
    .
    The API is agnostic to your choice of server.
category: Web
abi: 6797a68197c1bfbb89b2395d449177d2
exposed: True
exposed-modules:
    Network.HTTP.Media Network.HTTP.Media.Accept
    Network.HTTP.Media.Language Network.HTTP.Media.MediaType
    Network.HTTP.Media.RenderHeader
hidden-modules: Network.HTTP.Media.Language.Internal
                Network.HTTP.Media.MediaType.Internal Network.HTTP.Media.Quality
                Network.HTTP.Media.Utils
import-dirs: /usr/lib/ghc-8.6.5/site-local/http-media-0.7.1.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/http-media-0.7.1.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/http-media-0.7.1.3
hs-libraries: HShttp-media-0.7.1.3-526FRqXrDV23kO6QPxcRZi
depends:
    base-4.12.0.0 bytestring-0.10.8.2
    case-insensitive-1.2.1.0-L7BR5PaOPZy5cAHpLYQKhk containers-0.6.0.1
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-http-media/html/http-media.haddock
haddock-html: /usr/share/doc/haskell-http-media/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
